GDAPS - Generic Django Apps Plugin System — GDAPS documentation

# GDAPS - Generic Django Apps Plugin System

Welcome to the GDAPS documentation!

GDAPS is a plugin system that can be added to Django, to create applications that can be extended via plugins later.

Warning

While this software is tested, it is not guaranteed to be bug-free. It is in in an early development state.

Warning

As I completely abandoned Vue, Svelte, and other Javascript frontend frameworks in favour of other frameworks like Tetra (or Unicorn, Turbo-Django etc.), gdaps-frontend support for Vue is deprecated and will be dropped in near future.

Table of Contents

- Introduction
  - GDAPS working modes
- Installation
  - URL handling
  - Logging
  - Frontend support
  - Final step
- Usage
  - Creating plugins
  - The plugin AppConfig
  - Interfaces
  - Implementations
  - Using Implementations
  - Extending Django’s URL patterns
  - DRF API Routers
  - Per-plugin Settings
  - Admin site
- GDAPS template support
- API
  - Interfaces/Implementations
  - Plugin configuration and metadata
  - PluginManager
  - Helper functions
- Contributing
  - Code style

# License

I’d like to give back what I received from many Open Source software packages, and keep this library as open as possible, and it should stay this way. GDAPS is licensed under the General Public License, version 3.